==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/sn-ZW.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-one" => "'week' W 'of' MMM",
    "MMMMW-count-other" => "'week' W 'of' MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "'week' w 'of' Y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "sn-ZW",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Muv",
    "Chp",
    "Cht",
    "Chn",
    "Chs",
    "Mug",
    "Svo",
  ],
  day_format_narrow => [
    "M",
    "C",
    "C",
    "C",
    "C",
    "M",
    "S",
  ],
  day_format_wide => [
    "Muvhuro",
    "Chipiri",
    "Chitatu",
    "China",
    "Chishanu",
    "Mugovera",
    "Svondo",
  ],
  day_stand_alone_abbreviated => [
    "Muv",
    "Chp",
    "Cht",
    "Chn",
    "Chs",
    "Mug",
    "Svo",
  ],
  day_stand_alone_narrow => [
    "M",
    "C",
    "C",
    "C",
    "C",
    "M",
    "S",
  ],
  day_stand_alone_wide => [
    "Muvhuro",
    "Chipiri",
    "Chitatu",
    "China",
    "Chishanu",
    "Mugovera",
    "Svondo",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Kristo asati auya",
    "mugore ramambo vedu",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Shona",
  month_format_abbreviated => [
    "Ndi",
    "Kuk",
    "Kur",
    "Kub",
    "Chv",
    "Chk",
    "Chg",
    "Nya",
    "Gun",
    "Gum",
    "Mbu",
    "Zvi",
  ],
  month_format_narrow => [
    "N",
    "K",
    "K",
    "K",
    "C",
    "C",
    "C",
    "N",
    "G",
    "G",
    "M",
    "Z",
  ],
  month_format_wide => [
    "Ndira",
    "Kukadzi",
    "Kurume",
    "Kubvumbi",
    "Chivabvu",
    "Chikumi",
    "Chikunguru",
    "Nyamavhuvhu",
    "Gunyana",
    "Gumiguru",
    "Mbudzi",
    "Zvita",
  ],
  month_stand_alone_abbreviated => [
    "Ndi",
    "Kuk",
    "Kur",
    "Kub",
    "Chv",
    "Chk",
    "Chg",
    "Nya",
    "Gun",
    "Gum",
    "Mbu",
    "Zvi",
  ],
  month_stand_alone_narrow => [
    "N",
    "K",
    "K",
    "K",
    "C",
    "C",
    "C",
    "N",
    "G",
    "G",
    "M",
    "Z",
  ],
  month_stand_alone_wide => [
    "Ndira",
    "Kukadzi",
    "Kurume",
    "Kubvumbi",
    "Chivabvu",
    "Chikumi",
    "Chikunguru",
    "Nyamavhuvhu",
    "Gunyana",
    "Gumiguru",
    "Mbudzi",
    "Zvita",
  ],
  name => "Shona Zimbabwe",
  native_language => "chiShona",
  native_name => "chiShona Zimbabwe",
  native_script => undef,
  native_territory => "Zimbabwe",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4",
  ],
  script => undef,
  territory => "Zimbabwe",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/sn-ZW.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "sn-ZW",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Muv",
    "Chp",
    "Cht",
    "Chn",
    "Chs",
    "Mug",
    "Svo",
  ],
  day_format_narrow => [
    "M",
    "C",
    "C",
    "C",
    "C",
    "M",
    "S",
  ],
  day_format_wide => [
    "Muvhuro",
    "Chipiri",
    "Chitatu",
    "China",
    "Chishanu",
    "Mugovera",
    "Svondo",
  ],
  day_stand_alone_abbreviated => [
    "Muv",
    "Chp",
    "Cht",
    "Chn",
    "Chs",
    "Mug",
    "Svo",
  ],
  day_stand_alone_narrow => [
    "M",
    "C",
    "C",
    "C",
    "C",
    "M",
    "S",
  ],
  day_stand_alone_wide => [
    "Muvhuro",
    "Chipiri",
    "Chitatu",
    "China",
    "Chishanu",
    "Mugovera",
    "Svondo",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Kristo asati auya",
    "mugore ramambo vedu",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Shona",
  month_format_abbreviated => [
    "Ndi",
    "Kuk",
    "Kur",
    "Kub",
    "Chv",
    "Chk",
    "Chg",
    "Nya",
    "Gun",
    "Gum",
    "Mbu",
    "Zvi",
  ],
  month_format_narrow => [
    "N",
    "K",
    "K",
    "K",
    "C",
    "C",
    "C",
    "N",
    "G",
    "G",
    "M",
    "Z",
  ],
  month_format_wide => [
    "Ndira",
    "Kukadzi",
    "Kurume",
    "Kubvumbi",
    "Chivabvu",
    "Chikumi",
    "Chikunguru",
    "Nyamavhuvhu",
    "Gunyana",
    "Gumiguru",
    "Mbudzi",
    "Zvita",
  ],
  month_stand_alone_abbreviated => [
    "Ndi",
    "Kuk",
    "Kur",
    "Kub",
    "Chv",
    "Chk",
    "Chg",
    "Nya",
    "Gun",
    "Gum",
    "Mbu",
    "Zvi",
  ],
  month_stand_alone_narrow => [
    "N",
    "K",
    "K",
    "K",
    "C",
    "C",
    "C",
    "N",
    "G",
    "G",
    "M",
    "Z",
  ],
  month_stand_alone_wide => [
    "Ndira",
    "Kukadzi",
    "Kurume",
    "Kubvumbi",
    "Chivabvu",
    "Chikumi",
    "Chikunguru",
    "Nyamavhuvhu",
    "Gunyana",
    "Gumiguru",
    "Mbudzi",
    "Zvita",
  ],
  name => "Shona Zimbabwe",
  native_language => "chiShona",
  native_name => "chiShona Zimbabwe",
  native_script => undef,
  native_territory => "Zimbabwe",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4",
  ],
  script => undef,
  territory => "Zimbabwe",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
